@@ -31,11 +31,6 @@ def new_project(request):
         project = form.save(commit=False)
         project.owner = request.user
         project.save()
-
-        project.member_set.create(
-            user=project.owner,
-            type=MEMBER_OWNER,
-        )
         return HttpResponseRedirect(reverse('sentry-manage-project', args=[project.pk]))
 
     context = csrf(request)
@@ -142,7 +137,7 @@ def edit_project_member(request, project, member_id):
         'member': member,
         'project': project,
         'form': form,
-        'dsn': member.get_dsn(request.META['HTTP_HOST'], secure=request.is_secure()),
+        'dsn': member.get_dsn(request.get_host(), secure=request.is_secure()),
     })
 
     return render_to_response('sentry/projects/members/edit.html', context, request)
